@@ -81,6 +81,7 @@ class PubSub(object):
             group_id=self.kafka_group_id,
             bootstrap_servers=self.kafka_brokers,
             enable_auto_commit=self.kafka_enable_auto_commit,
+            auto_offset_reset="earliest",
         )
 
     def create_kafka_topics(self):
@@ -123,7 +124,7 @@ class PubSub(object):
 
         if self.enable_kafka:
             kafka_producer = self.get_kafka_producer()
-            future = kafka_producer.send(event, bytes(message_str, "utf-8"))
+            future = kafka_producer.send(event, message_str.encode("utf-8"))
             # Should we wait and make sure it is sent ?
             future.get(timeout=60)
 
@@ -150,10 +151,15 @@ class PubSub(object):
                 for record in consumer_records:
                     # we might be able to use another type of serializer here that is more efficient.
                     message_json = json.loads(record.value.decode("utf-8"))
-                    function = listeners.get(topic_partition.topic)
+                    functions = listeners.get(topic_partition.topic)
+
+                    if functions:
+                        if not isinstance(functions, list):
+                            logger.info("should be a list of functions but it is not, skipping")
+                        else:
+                            for f in functions:
+                                f(message_json)
 
-                    if function:
-                        function(message_json)
                     else:
                         logger.info(
                             "unable to find function %s in order to consume that topic" % (topic_partition.topic,)
